@@ -1,14 +1,12 @@
 from neo4j import GraphDatabase
+import sys
 def count_node(uri,user,pwd):
     try:
         driver=GraphDatabase.driver(uri=uri,auth=(user,pwd))
         connect=1
     except Exception as e:
-        connect=0
-        error=e
-    if(count==0):
-        print(error)
-    else:
+        sys.exit("check for hostname , username and password")
+    if(connect==1):
         session=driver.session()
         count_query="""match (n) return count(n) as count"""
         count_result=session.run(count_query)
